@@ -17,7 +17,8 @@ from servz.core.build_step import BuildStep
 class EndpointAppender(BuildStep):
 
     def __init__(self, **kwargs):
-        pass
+        super().__init__()
+        self._endpoints: list = list()
 
     def build_part(self, **kwargs):
 
@@ -26,7 +27,7 @@ class EndpointAppender(BuildStep):
     def get_results(self):
 
         return {
-            "endpoint_appender": self._build_flows
+            "endpoint_appender": self._endpoints
         }
 
     def build_runner_script(self, pipe):
