@@ -23,8 +23,6 @@ class PrefectArtifactBuilder(OrchestrationArtifactBuilder):
     def __init__(self, **kwargs):
 
         super().__init__(**kwargs)
-        print("*** Load Prefect Templates ****************")
-        print(f"package root: {ProjectConfig.package_root()}")
         self.__manifest_templates = {
             'prefect_flow_template': os.path.join(ProjectConfig.package_root(), 'templates/prefect_templates',
                                                 'prefect_flow_template'),
@@ -90,9 +88,10 @@ class PrefectArtifactBuilder(OrchestrationArtifactBuilder):
         with open(self.__manifest_templates['prefect_edge_template'], 'r') as f:
             edge_temp = f.read()
 
+        #  Todo: this is ugly, fix it sometime
         edge_str = ""
         deps = task.get('dependencies')
-        if len(deps) == 0:
+        if deps is None:
             return edge_str
         b = task["stage_name"].lower().replace(" ", "_")
 
